# unitorch.models.minigpt4

## MiniGPT4Blip2LlamaProcessor

::: unitorch.models.minigpt4.MiniGPT4Blip2LlamaProcessor

## MiniGPT4Blip2LlamaModel

::: unitorch.models.minigpt4.MiniGPT4Blip2LlamaModel

## MiniGPT4Blip2LlamaForGeneration

::: unitorch.models.minigpt4.MiniGPT4Blip2LlamaForGeneration
